@@ -1,5 +1,7 @@
 library(magrittr)
 
+skip_if_not_installed("styler")
+
 test_that("Cody tidying does not break code", {
     x <- readLines("messy_gapminder.txt")
     z <- tidy_all_code(x)
@@ -49,7 +51,7 @@ test_that("Cody tidying does not break code 2", {
 })
 
 test_that("print_code works OK", {
-    dat <- filterRows(iris, c(10, 20, 30))
+    dat <- remove_rows(iris, c(10, 20, 30))
     expect_equal(
         eval(parse(text = capture.output(print_code(dat)))),
         dat,
